/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define*/

/**
 * Time helper module.
 *
 * @module helpers/time
 * @namespace helpers/time
 * @memberof helpers
 */

define({
    name: 'helpers/time',
    def: function helpersTime() {
        'use strict';

        /**
         * Returns time components (hours, minutes, seconds).
         *
         * @memberof helpers/time
         * @public
         * @param {number} milliseconds
         * @returns {object}
         */
        function getTimeComponents(milliseconds) {
            var timeInMinutes = Math.floor(milliseconds / 1000 / 60),
                timeInSeconds = Math.floor(milliseconds / 1000),
                hours = Math.floor(timeInMinutes / 60),
                minutes = timeInMinutes - hours * 60,
                seconds = timeInSeconds - minutes * 60;

            return {hours: hours, minutes: minutes, seconds: seconds};
        }

        return {
            getTimeComponents: getTimeComponents
        };
    }
});
